import { useState } from "react";
import { useQuery } from "@tanstack/react-query";
import { useLocation } from "wouter";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Badge } from "@/components/ui/badge";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { useAuth } from "@/lib/auth";
import * as motion from "motion/react-client";
import {
  PlusCircle,
  Clock,
  Users,
  MessageCircle,
  TrendingUp,
  Eye,
  CheckCircle,
  LogOut,
} from "lucide-react";

interface Project {
  id: number;
  title: string;
  description: string;
  status: string;
  budget: { min: number; max: number };
  deadline: string;
  createdAt: string;
  shortlistCount?: number;
  messageCount?: number;
}

interface DashboardStats {
  totalProjects: number;
  activeProjects: number;
  totalDirectorsMatched: number;
  pendingResponses: number;
  completedProjects: number;
  messageCount: number;
}

export default function ClientDashboard() {
  const { user, logout } = useAuth();
  const [, setLocation] = useLocation();
  const [activeTab, setActiveTab] = useState("overview");
  const [hoveredBlocks, setHoveredBlocks] = useState<{
    [key: string]: boolean;
  }>({});

  // ✅ Block render until user is ready
  if (!user) return null;

  const isClient = user?.role === "client";

  // Single consolidated API call for dashboard data
  const { data: dashboardData, isLoading: dashboardLoading } = useQuery<{
    projects: Project[];
    stats: DashboardStats;
  }>({
    queryKey: ["/api/client/dashboard"],
    enabled: isClient,
    staleTime: 5 * 60 * 1000,
    refetchOnWindowFocus: false,
    refetchOnMount: false,
  });

  const projects = dashboardData?.projects || [];
  const stats = dashboardData?.stats;
  const isDashboardReady = !dashboardLoading;

  // Show content immediately, let individual components handle their loading states
  // This prevents the flash effect from a full-screen loading screen

  const dashboardBlocks = [
    {
      id: 'view-all-projects',
      title: 'View All Projects',
      subtitle: 'Browse your complete project portfolio',
      number: stats?.totalProjects || 0,
      color: 'from-[#6A8D8D] to-[#5A7A7A]',
      icon: Eye,
      shape: 'diamond',
      onClick: () => setLocation('/projects')
    },
    {
      id: 'active-projects',
      title: 'Active Projects',
      subtitle: 'projects in progress',
      number: stats?.activeProjects || 0,
      color: 'from-blue-400 to-blue-600',
      icon: Clock,
      shape: 'square',
      onClick: () => setLocation('/projects')
    },
    {
      id: 'create-new',
      title: 'Create New Project',
      subtitle: 'Start your next creative venture',
      number: '+',
      color: 'from-green-400 to-green-600',
      icon: PlusCircle,
      shape: 'hexagon',
      onClick: () => setLocation('/projects/new')
    },
    {
      id: 'completed-projects',
      title: 'Completed Projects',
      subtitle: 'successful collaborations',
      number: stats?.completedProjects || 0,
      color: 'from-purple-400 to-purple-600',
      icon: CheckCircle,
      shape: 'triangle',
      onClick: () => setLocation('/projects')
    },
    {
      id: 'messages',
      title: 'Messages',
      subtitle: 'director communications',
      number: stats?.messageCount || 0,
      color: 'from-pink-400 to-pink-600',
      icon: MessageCircle,
      shape: 'triangle',
      onClick: () => setLocation('/messages')
    },
    {
      id: 'total-directors',
      title: 'Directors Matched',
      subtitle: 'creative connections made',
      number: stats?.totalDirectorsMatched || 0,
      color: 'from-orange-400 to-orange-600',
      icon: Users,
      shape: 'circle',
      onClick: () => setLocation('/projects')
    },
    {
      id: 'pending-responses',
      title: 'Pending Responses',
      subtitle: 'awaiting director replies',
      number: stats?.pendingResponses || 0,
      color: 'from-yellow-400 to-yellow-600',
      icon: Clock,
      shape: 'square',
      onClick: () => setLocation('/messages')
    },
    {
      id: 'logout',
      title: 'Logout',
      subtitle: 'sign out of your account',
      number: '→',
      color: 'from-red-500 to-red-700',
      icon: LogOut,
      shape: 'hexagon',
      onClick: () => logout()
    }
  ];

  const getShapeElement = (shape: string, isHovered: boolean) => {
    const baseClasses = "stroke-white/30 fill-none stroke-2 transition-all duration-500";
    const hoverClasses = isHovered ? "stroke-white/60 scale-110" : "";
    
    switch (shape) {
      case 'diamond':
        return (
          <svg className={`w-32 h-32 ${baseClasses} ${hoverClasses}`} viewBox="0 0 100 100">
            <polygon points="50,10 90,50 50,90 10,50" />
          </svg>
        );
      case 'circle':
        return (
          <svg className={`w-32 h-32 ${baseClasses} ${hoverClasses}`} viewBox="0 0 100 100">
            <circle cx="50" cy="50" r="35" />
          </svg>
        );
      case 'square':
        return (
          <svg className={`w-32 h-32 ${baseClasses} ${hoverClasses}`} viewBox="0 0 100 100">
            <rect x="15" y="15" width="70" height="70" />
          </svg>
        );
      case 'triangle':
        return (
          <svg className={`w-32 h-32 ${baseClasses} ${hoverClasses}`} viewBox="0 0 100 100">
            <polygon points="50,15 85,75 15,75" />
          </svg>
        );
      case 'hexagon':
        return (
          <svg className={`w-32 h-32 ${baseClasses} ${hoverClasses}`} viewBox="0 0 100 100">
            <polygon points="25,20 75,20 90,50 75,80 25,80 10,50" />
          </svg>
        );
      default:
        return (
          <svg className={`w-32 h-32 ${baseClasses} ${hoverClasses}`} viewBox="0 0 100 100">
            <circle cx="50" cy="50" r="35" />
          </svg>
        );
    }
  };

  return (
    <div className="min-h-screen bg-black">
      <div className="grid grid-cols-2 lg:grid-cols-4 h-screen">
        {dashboardBlocks.map((block, index) => {
          const Icon = block.icon;
          return (
            <motion.div
              key={block.id}
              className={`relative bg-gradient-to-br ${block.color} cursor-pointer overflow-hidden group`}
              initial={{ opacity: 0, scale: 0.9 }}
              animate={{ opacity: 1, scale: 1 }}
              transition={{ duration: 0.6, delay: index * 0.1 }}
              onMouseEnter={() => setHoveredBlocks(prev => ({ ...prev, [block.id]: true }))}
              onMouseLeave={() => setHoveredBlocks(prev => ({ ...prev, [block.id]: false }))}
              onClick={block.onClick}
            >
              {/* Background geometric shapes */}
              <div className="absolute inset-0 flex items-center justify-center opacity-20">
                {getShapeElement(block.shape, hoveredBlocks[block.id])}
              </div>
              
              {/* Content */}
              <div className="relative z-10 p-6 h-full flex flex-col justify-between text-white">
                <div className="flex justify-between items-start">
                  <div className="text-4xl lg:text-6xl font-bold">
                    {block.number}
                  </div>
                  <Icon className="w-8 h-8 lg:w-10 lg:h-10 opacity-80" />
                </div>
                
                <div className="space-y-1">
                  <h3 className="text-lg lg:text-xl font-bold leading-tight">
                    {block.title}
                  </h3>
                  <p className="text-sm lg:text-base opacity-90 leading-tight">
                    {block.subtitle}
                  </p>
                </div>
              </div>
              
              {/* Hover effect overlay */}
              <motion.div
                className="absolute inset-0 bg-white/10"
                initial={{ opacity: 0 }}
                animate={{ opacity: hoveredBlocks[block.id] ? 1 : 0 }}
                transition={{ duration: 0.3 }}
              />
            </motion.div>
          );
        })}
      </div>
    </div>
  );
}
